@@ -150,8 +150,7 @@ if (isset($_GET["pgsql"])) {
 			function connect($server, $username, $password) {
 				global $adminer;
 				$db = $adminer->database();
-				$string = "pgsql:host='" . str_replace(":", "' port='", addcslashes($server, "'\\")) . "' options='-c client_encoding=utf8'";
-				$this->dsn("$string dbname='" . ($db != "" ? addcslashes($db, "'\\") : "postgres") . "'", $username, $password);
+				$this->dsn("pgsql:host='" . str_replace(":", "' port='", addcslashes($server, "'\\")) . "' client_encoding=utf8 dbname='" . ($db != "" ? addcslashes($db, "'\\") : "postgres") . "'", $username, $password); //! client_encoding is supported since 9.1 but we can't yet use min_version here
 				//! connect without DB in case of an error
 				return true;
 			}
@@ -292,7 +291,7 @@ if (isset($_GET["pgsql"])) {
 
 	function db_collation($db, $collations) {
 		global $connection;
-		return $connection->result("SHOW LC_COLLATE"); //! respect $db
+		return $connection->result("SELECT datcollate FROM pg_database WHERE datname = " . q($db));
 	}
 
 	function engines() {
@@ -327,7 +326,7 @@ ORDER BY 1";
 		foreach (get_rows("SELECT c.relname AS \"Name\", CASE c.relkind WHEN 'r' THEN 'table' WHEN 'm' THEN 'materialized view' ELSE 'view' END AS \"Engine\", pg_relation_size(c.oid) AS \"Data_length\", pg_total_relation_size(c.oid) - pg_relation_size(c.oid) AS \"Index_length\", obj_description(c.oid, 'pg_class') AS \"Comment\", " . (min_version(12) ? "''" : "CASE WHEN c.relhasoids THEN 'oid' ELSE '' END") . " AS \"Oid\", c.reltuples as \"Rows\", n.nspname
 FROM pg_class c
 JOIN pg_namespace n ON(n.nspname = current_schema() AND n.oid = c.relnamespace)
-WHERE relkind IN ('r', 'm', 'v', 'f')
+WHERE relkind IN ('r', 'm', 'v', 'f', 'p')
 " . ($name != "" ? "AND relname = " . q($name) : "ORDER BY relname")
 		) as $row) { //! Index_length, Auto_increment
 			$return[$row["Name"]] = $row;
@@ -350,7 +349,7 @@ WHERE relkind IN ('r', 'm', 'v', 'f')
 			'timestamp with time zone' => 'timestamptz',
 		);
 
-		$identity_column = min_version(10) ? "(a.attidentity = 'd')::int" : '0';
+		$identity_column = min_version(10) ? 'a.attidentity' : '0';
 
 		foreach (get_rows("SELECT a.attname AS field, format_type(a.atttypid, a.atttypmod) AS full_type, pg_get_expr(d.adbin, d.adrelid) AS default, a.attnotnull::int, col_description(c.oid, a.attnum) AS comment, $identity_column AS identity
 FROM pg_class c
@@ -375,8 +374,8 @@ ORDER BY a.attnum"
 				$row["type"] = $type;
 				$row["full_type"] = $row["type"] . $length . $addon . $array;
 			}
-			if ($row['identity']) {
-				$row['default'] = 'GENERATED BY DEFAULT AS IDENTITY';
+			if (in_array($row['identity'], array('a', 'd'))) {
+				$row['default'] = 'GENERATED ' . ($row['identity'] == 'd' ? 'BY DEFAULT' : 'ALWAYS') . ' AS IDENTITY';
 			}
 			$row["null"] = !$row["attnotnull"];
 			$row["auto_increment"] = $row['identity'] || preg_match('~^nextval\(~i', $row["default"]);
@@ -436,9 +435,26 @@ ORDER BY conkey, conname") as $row) {
 		return $return;
 	}
 
+	function constraints($table) {
+		global $on_actions;
+		$return = array();
+		foreach (get_rows("SELECT conname, consrc
+FROM pg_catalog.pg_constraint
+INNER JOIN pg_catalog.pg_namespace ON pg_constraint.connamespace = pg_namespace.oid
+INNER JOIN pg_catalog.pg_class ON pg_constraint.conrelid = pg_class.oid AND pg_constraint.connamespace = pg_class.relnamespace
+WHERE pg_constraint.contype = 'c'
+AND conrelid != 0 -- handle only CONSTRAINTs here, not TYPES
+AND nspname = current_schema()
+AND relname = " . q($table) . "
+ORDER BY connamespace, conname") as $row) {
+			$return[$row['conname']] = $row['consrc'];
+		}
+		return $return;
+	}
+
 	function view($name) {
 		global $connection;
-		return array("select" => trim($connection->result("SELECT pg_get_viewdef(" . $connection->result("SELECT oid FROM pg_class WHERE relname = " . q($name)) . ")")));
+		return array("select" => trim($connection->result("SELECT pg_get_viewdef(" . $connection->result("SELECT oid FROM pg_class WHERE relnamespace = (SELECT oid FROM pg_namespace WHERE nspname = current_schema()) AND relname = " . q($name)) . ")")));
 	}
 
 	function collations() {
@@ -475,7 +491,7 @@ ORDER BY conkey, conname") as $row) {
 	}
 
 	function auto_increment() {
-		return "";
+		return (min_version(11) ? " PRIMARY KEY" : "");
 	}
 
 	function alter_table($table, $name, $fields, $foreign, $comment, $engine, $collation, $auto_increment, $partitioning) {
@@ -493,7 +509,7 @@ ORDER BY conkey, conname") as $row) {
 				$val5 = $val[5];
 				unset($val[5]);
 				if (isset($val[6]) && $field[0] == "") { // auto_increment
-					$val[1] = ($val[1] == "bigint" ? " big" : " ") . "serial";
+					$val[1] = ($val[1] == " bigint" ? " big" : ($val[1] == " smallint" ? " small" : " ")) . "serial";
 				}
 				if ($field[0] == "") {
 					$alter[] = ($table != "" ? "ADD " : "  ") . implode($val);
@@ -704,6 +720,23 @@ AND typelem = 0"
 		return $return;
 	}
 
+	// create_sql() produces CREATE TABLE without FK CONSTRAINTs
+	// foreign_keys_sql() produces all FK CONSTRAINTs as ALTER TABLE ... ADD CONSTRAINT
+	// so that all FKs can be added after all tables have been created, avoiding any need to reorder CREATE TABLE statements in order of their FK dependencies
+	function foreign_keys_sql($table) {
+		$return = "";
+
+		$status = table_status($table);
+		$fkeys = foreign_keys($table);
+		ksort($fkeys);
+
+		foreach ($fkeys as $fkey_name => $fkey) {
+			$return .= "ALTER TABLE ONLY " . idf_escape($status['nspname']) . "." . idf_escape($status['Name']) . " ADD CONSTRAINT " . idf_escape($fkey_name) . " $fkey[definition] " . ($fkey['deferrable'] ? 'DEFERRABLE' : 'NOT DEFERRABLE') . ";\n";
+		}
+
+		return ($return ? "$return\n" : $return);
+	}
+
 	function create_sql($table, $auto_increment, $style) {
 		global $connection;
 		$return = '';
@@ -718,8 +751,7 @@ AND typelem = 0"
 		$fields = fields($table);
 		$indexes = indexes($table);
 		ksort($indexes);
-		$fkeys = foreign_keys($table);
-		ksort($fkeys);
+		$constraints = constraints($table);
 
 		if (!$status || empty($fields)) {
 			return false;
@@ -759,9 +791,8 @@ AND typelem = 0"
 			}
 		}
 
-		// foreign keys
-		foreach ($fkeys as $fkey_name => $fkey) {
-			$return_parts[] = "CONSTRAINT " . idf_escape($fkey_name) . " $fkey[definition] " . ($fkey['deferrable'] ? 'DEFERRABLE' : 'NOT DEFERRABLE');
+		foreach ($constraints as $conname => $consrc) {
+			$return_parts[] = "CONSTRAINT " . idf_escape($conname) . " CHECK $consrc";
 		}
 
 		$return .= implode(",\n    ", $return_parts) . "\n) WITH (oids = " . ($status['Oid'] ? 'true' : 'false') . ");";
