@@ -73,18 +73,12 @@ if ($auth) {
 		redirect(auth_url($vendor, $server, $username, $db));
 	}
 	
-} elseif ($_POST["logout"]) {
-	if ($has_token && !verify_token()) {
-		page_header(lang('Logout'), lang('Invalid CSRF token. Send the form again.'));
-		page_footer("db");
-		exit;
-	} else {
-		foreach (array("pwds", "db", "dbs", "queries") as $key) {
-			set_session($key, null);
-		}
-		unset_permanent();
-		redirect(substr(preg_replace('~\b(username|db|ns)=[^&]*&~', '', ME), 0, -1), lang('Logout successful.') . ' ' . lang('Thanks for using Adminer, consider <a href="https://www.adminer.org/en/donation/">donating</a>.'));
+} elseif ($_POST["logout"] && (!$has_token || verify_token())) {
+	foreach (array("pwds", "db", "dbs", "queries") as $key) {
+		set_session($key, null);
 	}
+	unset_permanent();
+	redirect(substr(preg_replace('~\b(username|db|ns)=[^&]*&~', '', ME), 0, -1), lang('Logout successful.') . ' ' . lang('Thanks for using Adminer, consider <a href="https://www.adminer.org/en/donation/">donating</a>.'));
 	
 } elseif ($permanent && !$_SESSION["pwds"]) {
 	session_regenerate_id();
@@ -162,7 +156,7 @@ stop_session(true);
 
 if (isset($_GET["username"]) && is_string(get_password())) {
 	list($host, $port) = explode(":", SERVER, 2);
-	if (+$port && ($port < 1024 || $port > 65535)) {
+	if (preg_match('~^\s*([-+]?\d+)~', $port, $match) && ($match[1] < 1024 || $match[1] > 65535)) { // is_numeric('80#') would still connect to port 80
 		auth_error(lang('Connecting to privileged ports is not allowed.'));
 	}
 	check_invalid_login();
@@ -176,6 +170,12 @@ if (!is_object($connection) || ($login = $adminer->login($_GET["username"], get_
 	auth_error($error . (preg_match('~^ | $~', get_password()) ? '<br>' . lang('There is a space in the input password which might be the cause.') : ''));
 }
 
+if ($_POST["logout"] && $has_token && !verify_token()) {
+	page_header(lang('Logout'), lang('Invalid CSRF token. Send the form again.'));
+	page_footer("db");
+	exit;
+}
+
 if ($auth && $_POST["token"]) {
 	$_POST["token"] = $token; // reset token after explicit login
 }
