@@ -1,5 +1,10 @@
 <?php
-error_reporting(6133); // errors
+function adminer_errors($errno, $errstr) {
+	return !!preg_match('~^(Trying to access array offset on value of type null|Undefined array key)~', $errstr);
+}
+
+error_reporting(6135); // errors and warnings
+set_error_handler('adminer_errors', 2); // 2 - E_WARNING
 
 include "../adminer/include/coverage.inc.php";
 
