@@ -23,6 +23,7 @@ $langs = array(
 	'id' => 'Bahasa Indonesia', // Ivan Lanin - http://ivan.lanin.org
 	'it' => 'Italiano', // Alessandro Fiorotto, Paolo Asperti
 	'ja' => '日本語', // Hitoshi Ozawa - http://sourceforge.jp/projects/oss-ja-jpn/releases/
+	'ka' => 'ქართული', // Saba Khmaladze skhmaladze@uglt.org
 	'ko' => '한국어', // dalli - skcha67@gmail.com
 	'lt' => 'Lietuvių', // Paulius Leščinskas - http://www.lescinskas.lt
 	'ms' => 'Bahasa Melayu', // Pisyek
@@ -36,6 +37,7 @@ $langs = array(
 	'sk' => 'Slovenčina', // Ivan Suchy - http://www.ivansuchy.com, Juraj Krivda - http://www.jstudio.cz
 	'sl' => 'Slovenski', // Matej Ferlan - www.itdinamik.com, matej.ferlan@itdinamik.com
 	'sr' => 'Српски', // Nikola Radovanović - cobisimo@gmail.com
+	'sv' => 'Svenska', // rasmusolle - https://github.com/rasmusolle
 	'ta' => 'த‌மிழ்', // G. Sampath Kumar, Chennai, India, sampathkumar11@gmail.com
 	'th' => 'ภาษาไทย', // Panya Saraphi, elect.tu@gmail.com - http://www.opencart2u.com/
 	'tr' => 'Türkçe', // Bilgehan Korkmaz - turktron.com
