@@ -1,8 +1,8 @@
 <?php
 // PDO can be used in several database drivers
 if (extension_loaded('pdo')) {
-	/*abstract*/ class Min_PDO extends PDO {
-		var $_result, $server_info, $affected_rows, $errno, $error;
+	/*abstract*/ class Min_PDO {
+		var $_result, $server_info, $affected_rows, $errno, $error, $pdo;
 		
 		function __construct() {
 			global $adminer;
@@ -14,21 +14,26 @@ if (extension_loaded('pdo')) {
 		
 		function dsn($dsn, $username, $password, $options = array()) {
 			try {
-				parent::__construct($dsn, $username, $password, $options);
+				$this->pdo = new PDO($dsn, $username, $password, $options);
 			} catch (Exception $ex) {
 				auth_error(h($ex->getMessage()));
 			}
-			$this->setAttribute(13, array('Min_PDOStatement')); // 13 - PDO::ATTR_STATEMENT_CLASS
-			$this->server_info = @$this->getAttribute(4); // 4 - PDO::ATTR_SERVER_VERSION
+			$this->pdo->setAttribute(3, 1); //  3 - PDO::ATTR_ERRMODE, 1 - PDO::ERRMODE_WARNING
+			$this->pdo->setAttribute(13, array('Min_PDOStatement')); // 13 - PDO::ATTR_STATEMENT_CLASS
+			$this->server_info = @$this->pdo->getAttribute(4); // 4 - PDO::ATTR_SERVER_VERSION
 		}
 		
 		/*abstract function select_db($database);*/
 		
+		function quote($string) {
+			return $this->pdo->quote($string);
+		}
+		
 		function query($query, $unbuffered = false) {
-			$result = parent::query($query);
+			$result = $this->pdo->query($query);
 			$this->error = "";
 			if (!$result) {
-				list(, $this->errno, $this->error) = $this->errorInfo();
+				list(, $this->errno, $this->error) = $this->pdo->errorInfo();
 				if (!$this->error) {
 					$this->error = lang('Unknown error.');
 				}
