@@ -186,7 +186,7 @@ $translations = array(
 	'original' => 'প্রকৃত',
 	'Tables have been dropped.' => 'টেবিলসমূহ মুছে ফেলা হয়েছে।',
 	'%d item(s) have been affected.' => '%d টি বিষয়বস্তু প্রভাবিত হয়েছে',
-	'whole result' => 'সম্পূর্ণ ফলাফল',
+	'Whole result' => 'সম্পূর্ণ ফলাফল',
 	'Clone' => 'ক্লোন',
 	'Maximum number of allowed fields exceeded. Please increase %s.' => 'অনুমোদিত ফিল্ড এর সর্বাধিক সংখ্যা অতিক্রম করে গেছে। অনুগ্রহপূর্বক %s বৃদ্ধি করুন।',
 	'Partition by' => 'পার্টিশন যার মাধ্যমে',
