@@ -234,7 +234,7 @@ $translations = array(
 	'Sort' => 'Ταξινόμηση',
 	'descending' => 'Φθίνουσα',
 	'Limit' => 'Όριο',
-	'Limit rows' => 'Περιοριμός σειρών',
+	'Limit rows' => 'Περιορισμός σειρών',
 	'Text length' => 'Μήκος κειμένου',
 	'Action' => 'Ενέργεια',
 	'Full table scan' => 'Πλήρης σάρωση πινάκων',
