@@ -289,4 +289,15 @@ $translations = array(
 	'Saving' => 'Сохранение',
 	'yes' => 'Да',
 	'no' => 'Нет',
+	'Drop %s?' => 'Удалить %s?',
+	'overwrite' => 'перезаписать',
+	'DB' => 'DB',
+	'Warnings' => 'Предупреждения',
+	'Adminer does not support accessing a database without a password, <a href="https://www.adminer.org/en/password/"%s>more information</a>.' => 'Adminer не поддерживает доступ к базе данных без пароля, <a href="https://www.adminer.org/en/password/"%s>больше информации</a>.',
+	'Thanks for using Adminer, consider <a href="https://www.adminer.org/en/donation/">donating</a>.' => 'Спасибо за использование Adminer, рассмотрите возможность <a href="https://www.adminer.org/en/donation/">пожертвования</a>.',
+	'The action will be performed after successful login with the same credentials.' => 'Действие будет выполнено после успешного входа в систему с теми же учетными данными.',
+	'Connecting to privileged ports is not allowed.' => 'Подключение к привилегированным портам не допускается.',
+	'There is a space in the input password which might be the cause.' => 'В введеном пароле есть пробел, это может быть причиною.',
+	'Unknown error.' => 'Неизвестная ошибка.',
+	'Database does not support password.' => 'База данных не поддерживает пароль.',
 );
